pub struct ScalarSensitivity<SolveState: State, Rx, Tx>where
DefaultAllocator: Allocator<SolveState::Size> + Allocator<SolveState::VecLength> + Allocator<SolveState::Size, SolveState::Size> + Allocator<U1, SolveState::Size>,{
pub sensitivity_row: OMatrix<f64, U1, SolveState::Size>,
pub _rx: PhantomData<Rx>,
pub _tx: PhantomData<Tx>,
}Fields
sensitivity_row: OMatrix<f64, U1, SolveState::Size>_rx: PhantomData<Rx>_tx: PhantomData<Tx>Trait Implementations
Sourceimpl ScalarSensitivityT<GroundAsset, GroundAsset, InterlinkTxSpacecraft> for ScalarSensitivity<GroundAsset, GroundAsset, InterlinkTxSpacecraft>
impl ScalarSensitivityT<GroundAsset, GroundAsset, InterlinkTxSpacecraft> for ScalarSensitivity<GroundAsset, GroundAsset, InterlinkTxSpacecraft>
Sourcefn new(
msr_type: MeasurementType,
msr: &Measurement,
rx: &GroundAsset,
tx: &InterlinkTxSpacecraft,
almanac: Arc<Almanac>,
) -> Result<Self, ODError>
fn new( msr_type: MeasurementType, msr: &Measurement, rx: &GroundAsset, tx: &InterlinkTxSpacecraft, almanac: Arc<Almanac>, ) -> Result<Self, ODError>
First, we ensure that the transmitter vehicle is expressed in the same frame as the ground asset. Then we compute the AER as seen from the ground asset.
Sourceimpl ScalarSensitivityT<Spacecraft, Spacecraft, GroundStation> for ScalarSensitivity<Spacecraft, Spacecraft, GroundStation>
impl ScalarSensitivityT<Spacecraft, Spacecraft, GroundStation> for ScalarSensitivity<Spacecraft, Spacecraft, GroundStation>
fn new( msr_type: MeasurementType, msr: &Measurement, rx: &Spacecraft, tx: &GroundStation, almanac: Arc<Almanac>, ) -> Result<Self, ODError>